@@ -4,11 +4,10 @@
 # @file         expire-sessions
 # @author       Rick Kennell <kennell@purdue.edu>
 # @author	    John Rosheck <jrosheck@purdue.edu>
-# @copyright    Copyright (c) 2005-2012 Purdue University. All rights reserved.
+# @copyright    Copyright (c) 2005-2012 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2005-2012 Purdue University
-# All rights reserved.
+# Copyright (c) 2005-2012 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -26,7 +25,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-# HUBzero is a registered trademark of Purdue University.
+# HUBzero is a registered trademark of HUBzero Foundation, LLC.s
 
 import os,pwd,sys,time,MySQLdb,signal
 
@@ -147,6 +146,48 @@ def mysql_act(c,cmd):
   except MySQLdb.MySQLError, (num, expl):
     return expl
 
+
+#=============================================================================
+# Check pidfile
+#
+# @TODO should probably check if process is actually an instance
+#       of expire-sessions
+#=============================================================================
+def checkpidfile():
+
+  try:
+    f = open(pidfile,"r")
+  except:
+    return True
+
+  try:    
+    pid = int(f.read())
+  except:
+    #log("Unable to open pidfile %s" % pidfile)
+    return False
+      
+  if (pid <= 1):
+    #log("Invalid pid found in pidfile %s" % pidfile)
+    return False
+
+  if os.path.exists("/proc/%s" % pid):
+  	print(" [expire-sessions (pid %s) already running] " % pid),
+  	return 0
+  else:
+    return 1
+
+#=============================================================================
+# Remove pidfile
+#=============================================================================
+def rmpidfile():
+  try:
+    os.remove(pidfile)
+  except:
+    #log("Unable to remove pidfile %s" % pidfile)
+    return False
+
+  return true
+
 #=============================================================================
 # Daemonize.
 #=============================================================================
@@ -182,7 +223,8 @@ def change_user(username):
 #=============================================================================
 def sighandler(sig,frame):
   log("Caught signal %d.  Exiting." % sig)
-  sys.exit(1)
+  rmpidfile()
+  sys.exit(2)
 
 #=============================================================================
 # Do the work of terminating a session.
@@ -201,11 +243,15 @@ signal.signal(signal.SIGHUP, sighandler)
 signal.signal(signal.SIGINT, sighandler)
 signal.signal(signal.SIGQUIT, sighandler)
 signal.signal(signal.SIGTERM, sighandler)
+ 
+if not checkpidfile():
+  sys.exit(1)
 
 if not foreground:
   daemonize()
   change_user("www-data")
   openlog(logfile_name)
+
   log("Server is ready.")
 
 while 1:
